0.9.9 API documentation: matrix_float4x4.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_float4x4.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_mat4x4.hpp"
6
7 namespace glm
8 {
11
15 typedef mat<4, 4, float, defaultp> mat4x4;
16
20 typedef mat<4, 4, float, defaultp> mat4;
21
23 }//namespace glm
glm::mat4x4
mat< 4, 4, float, defaultp > mat4x4
4 columns of 4 components matrix of single-precision floating-point numbers.
Definition: matrix_float4x4.hpp:15
glm::mat4
mat< 4, 4, float, defaultp > mat4
4 columns of 4 components matrix of single-precision floating-point numbers.
Definition: matrix_float4x4.hpp:20
glm
Definition: common.hpp:20